SuggestlyRatingPopup class

Dialog for collecting a user rating and optional comment.

Inheritance

Constructors

SuggestlyRatingPopup({Key? key, required String title, String? message, int? initialRating, String? initialComment, int maxRating = 5, TextInputPopupThemeData? themeOverrides, String ratingLabelBuilder(int rating)?, required SubmissionIdentity identity, SuggestlyUser? userDetails, FeedbackEligibility? initialEligibility, ApplicationSummary? applicationSummary, VoidCallback? onCancel, String? submitLabel, String? cancelLabel})
const

Properties

applicationSummary ApplicationSummary?
final
cancelLabel String?
final
hashCode int
The hash code for this object.
no setterinherited
identity SubmissionIdentity
final
initialComment String?
final
initialEligibility FeedbackEligibility?
final
initialRating int?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxRating int
final
message String?
final
onCancel VoidCallback?
final
ratingLabelBuilder String Function(int rating)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitLabel String?
final
themeOverrides TextInputPopupThemeData?
final
title String
final
userDetails SuggestlyUser?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SuggestlyRatingPopup>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, {required String title, String? message, int? initialRating, String? initialComment, TextInputPopupThemeData? themeOverrides, String ratingLabelBuilder(int rating)?, required SubmissionIdentity identity, VoidCallback? onCancel, String? submitLabel, String? cancelLabel, bool includeCancelAction = true}) Future<SuggestlyPopupResult<FeedbackSubmissionResult>>
Displays the rating popup using showDialog.