FeedbackEligibility class
Constructors
- FeedbackEligibility({required bool canSubmit, required FeedbackEligibilityReason reason, String? message, required int statusCode, required String applicationStatus, required String publishedVisibility, required bool isCollaborator, required bool isPrimaryOwner, required bool isReviewer})
-
const
Properties
- applicationStatus → String
-
final
- canSubmit → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAllowed → bool
-
no setter
- isCollaborator → bool
-
final
- isPrimaryOwner → bool
-
final
- isReviewer → bool
-
final
- message → String?
-
final
- publishedVisibility → String
-
final
- reason → FeedbackEligibilityReason
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited