SubmissionIdentity class
Represents the authenticated identity and submission token for a public user.
Constructors
Properties
- created → bool
-
final
- email → String
-
final
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFresh → bool
-
no setter
- reviewerAlreadyExists → bool
-
final
- reviewerCreated → bool
-
final
- reviewerSkipped → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
final
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited